==> haskell-async-2.2.4-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 async
version:              2.2.4
visibility:           public
id:                   async-2.2.4-8fHP2vwSLWH996zJYB8hGm
key:                  async-2.2.4-8fHP2vwSLWH996zJYB8hGm
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2012
maintainer:           Simon Marlow <marlowsd@gmail.com>
author:               Simon Marlow
homepage:             https://github.com/simonmar/async
synopsis:             Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.

    Using @Async@ is safer than using threads in two
    ways:

    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.

    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').

category:             Concurrency
abi:                  f099c75d8e81e79023f9bbcb8bb97a78
exposed:              True
exposed-modules:      Control.Concurrent.Async
import-dirs:          /usr/lib/ghc-9.0.2/site-local/async-2.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/async-2.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-async
hs-libraries:         HSasync-2.2.4-8fHP2vwSLWH996zJYB8hGm
depends:
    base-4.15.1.0 hashable-1.4.2.0-CqBnUCWXkAoBvuSxaiTiK1 stm-2.5.0.0

haddock-interfaces:   /usr/share/doc/haskell-async/html/async.haddock
haddock-html:         /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-async-2.2.4-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 async
version:              2.2.4
visibility:           public
id:                   async-2.2.4-17F2m0fMLmE9RexONjnSWz
key:                  async-2.2.4-17F2m0fMLmE9RexONjnSWz
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2012
maintainer:           Simon Marlow <marlowsd@gmail.com>
author:               Simon Marlow
homepage:             https://github.com/simonmar/async
synopsis:             Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.

    Using @Async@ is safer than using threads in two
    ways:

    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.

    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').

category:             Concurrency
abi:                  bd0cb73216ae245edeba25a804501222
exposed:              True
exposed-modules:      Control.Concurrent.Async
import-dirs:          /usr/lib/ghc-9.0.2/site-local/async-2.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/async-2.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-async
hs-libraries:         HSasync-2.2.4-17F2m0fMLmE9RexONjnSWz
depends:
    base-4.15.1.0 hashable-1.4.2.0-FGfJ6SPjJOQC6UzILfUyUL stm-2.5.0.0

haddock-interfaces:   /usr/share/doc/haskell-async/html/async.haddock
haddock-html:         /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
